@@ -30,13 +30,13 @@ qi_data_directory.future_tick_cache = tick_path
 qi_data_directory.future_min = min_path
 qi_data_directory.future_day = day_path
 
-instrument_id = 'eg9999'
-begin_trading_date = datetime.datetime(2016, 1, 1)
-end_trading_date = datetime.datetime(2018, 12, 20)
-interval = 1
+instrument_id = 'j9999'
+begin_trading_date = datetime.datetime(2022, 12, 7)
+end_trading_date = datetime.datetime(2023, 2, 8)
+interval = 30
 bar_type = EnumBarType.minute
 qi_data_controller = QiDataController(qi_data_directory)
-bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, 1, bar_type, begin_trading_date, end_trading_date)
+bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
 for bar in bar_series:
     print(bar.to_string())
 
